if(!self.define){let e,n={};const s=(s,i)=>(s=new URL(s+".js",i).href,n[s]||new Promise(n=>{if("document"in self){const e=document.createElement("script");e.src=s,e.onload=n,document.head.appendChild(e)}else e=s,importScripts(s),n()}).then(()=>{let e=n[s];if(!e)throw new Error(`Module ${s} didn’t register its module`);return e}));self.define=(i,t)=>{const o=e||("document"in self?document.currentScript.src:"")||location.href;if(n[o])return;let r={};const c=e=>s(e,o),l={module:{uri:o},exports:r,require:c};n[o]=Promise.all(i.map(e=>l[e]||c(e))).then(e=>(t(...e),r))}}define(["./workbox-4245c4a1"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"assets/index-Bqb88LVT.css",revision:null},{url:"assets/index-vtnI5AxH.js",revision:null},{url:"index.html",revision:"d94174ae69e4957e27f857f62d15099a"},{url:"registerSW.js",revision:"1872c500de691dce40960bb85481de07"},{url:"icon-192x192.png",revision:"b357a19c87624c7c4d131aeeb4ae677f"},{url:"icon-512x512.png",revision:"b357a19c87624c7c4d131aeeb4ae677f"},{url:"manifest.webmanifest",revision:"0486dfb169e38749e960d6b333b533c7"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("index.html"))),e.registerRoute(/^https:\/\/fonts\.(?:gstatic|googleapis)\.com\/.*$/i,new e.CacheFirst({cacheName:"google-fonts",plugins:[new e.ExpirationPlugin({maxEntries:4,maxAgeSeconds:31536e3})]}),"GET"),e.registerRoute(/^https:\/\/fonts\.gstatic\.com\/.*/i,new e.CacheFirst({cacheName:"google-fonts-webfonts",plugins:[new e.ExpirationPlugin({maxEntries:30,maxAgeSeconds:31536e3})]}),"GET")});
//# sourceMappingURL=sw.js.map
